BloomAction class
Annotation marking a server-side or client form action handler for a route.
Actions handle mutations, form submissions, and user interactions.
Example:
@BloomAction()
Future<ActionResult> updateProfile(BloomRouteContext ctx) async {
// Update user profile
return ActionResult.success();
}
Constructors
- BloomAction()
-
Creates a BloomAction annotation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited