token property
Reactive signal containing the current authentication bearer token, or null if unauthenticated.
Implementation
@override
ReadonlySignal<String?> get token => _token.readonly();
Reactive signal containing the current authentication bearer token, or null if unauthenticated.
@override
ReadonlySignal<String?> get token => _token.readonly();