BloomBreadcrumbLevel enum
Severity level for breadcrumb events.
Values
- debug → const BloomBreadcrumbLevel
-
Debug-level detail.
- info → const BloomBreadcrumbLevel
-
Informational breadcrumb event.
- warning → const BloomBreadcrumbLevel
-
Warning event that may precede an error.
- error → const BloomBreadcrumbLevel
-
Error breadcrumb event.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Serializes level to JSON string.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
String value) → BloomBreadcrumbLevel -
Parses level from string
value.
Constants
-
values
→ const List<
BloomBreadcrumbLevel> - A constant List of the values in this enum, in order of their declaration.