add method
Adds a breadcrumb to the ring buffer, evicting the oldest if capacity is exceeded.
Implementation
void add(BloomBreadcrumb breadcrumb) {
if (_queue.length >= maxCapacity) {
_queue.removeFirst();
}
_queue.addLast(breadcrumb);
}
Adds a breadcrumb to the ring buffer, evicting the oldest if capacity is exceeded.
void add(BloomBreadcrumb breadcrumb) {
if (_queue.length >= maxCapacity) {
_queue.removeFirst();
}
_queue.addLast(breadcrumb);
}