isOffline property
bool
get
isOffline
Whether the device is currently in a simulated offline state.
Implementation
static bool get isOffline => _isOffline;
Whether the device is currently in a simulated offline state.
static bool get isOffline => _isOffline;