BloomLifecycleHook class

Metadata annotation declaring a host application lifecycle listener.

Methods annotated with @BloomLifecycleHook() receive lifecycle transitions (resumed, paused, detached).

Example:

@BloomLifecycleHook()
void onHostPause() {
  // Release hardware locks
}

Constructors

BloomLifecycleHook()
Creates a BloomLifecycleHook annotation.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited