didChangeAppLifecycleState method

  1. @override
void didChangeAppLifecycleState(
  1. AppLifecycleState state
)
override

Called when the system puts the app in the background or returns the app to the foreground.

An example of implementing this method is provided in the class-level documentation for the WidgetsBindingObserver class.

This method exposes notifications from SystemChannels.lifecycle.

See also:

Implementation

@override
void didChangeAppLifecycleState(AppLifecycleState state) {
  logger.debug('App lifecycle state changed to: $state');
  switch (state) {
    case AppLifecycleState.resumed:
      for (final obs in List<BloomLifecycleObserver>.from(_observers)) {
        obs.onAppResumed();
      }
      break;
    case AppLifecycleState.inactive:
      for (final obs in List<BloomLifecycleObserver>.from(_observers)) {
        obs.onAppInactive();
      }
      break;
    case AppLifecycleState.paused:
      for (final obs in List<BloomLifecycleObserver>.from(_observers)) {
        obs.onAppPaused();
      }
      break;
    case AppLifecycleState.detached:
      for (final obs in List<BloomLifecycleObserver>.from(_observers)) {
        obs.onAppDetached();
      }
      break;
    case AppLifecycleState.hidden:
      for (final obs in List<BloomLifecycleObserver>.from(_observers)) {
        obs.onAppHidden();
      }
      break;
  }
}