onAppDetached method
void
onAppDetached()
Called when the application engine is detached from the host platform.
Implementation
void onAppDetached() {}
Called when the application engine is detached from the host platform.
void onAppDetached() {}