onAppInactive method
void
onAppInactive()
Called when the application enters an inactive state (e.g. phone call or system dialog).
Implementation
void onAppInactive() {}
Called when the application enters an inactive state (e.g. phone call or system dialog).
void onAppInactive() {}