onAppResumed method
void
onAppResumed()
Called when the application transitions to the foreground resumed state.
Implementation
void onAppResumed() {}
Called when the application transitions to the foreground resumed state.
void onAppResumed() {}