hardware property
The hardware device or sensor identifier that was unavailable (e.g. 'camera', 'bluetooth').
Implementation
final String hardware;
The hardware device or sensor identifier that was unavailable (e.g. 'camera', 'bluetooth').
final String hardware;