onEvent property
Event callback invoked when the native view emits a platform event across the method channel.
Implementation
final void Function(String eventName, dynamic payload)? onEvent;
Event callback invoked when the native view emits a platform event across the method channel.
final void Function(String eventName, dynamic payload)? onEvent;