importance property
Importance level of notifications posted to this channel (defaults to NotificationImportance.high).
Implementation
final NotificationImportance importance;
Importance level of notifications posted to this channel (defaults to NotificationImportance.high).
final NotificationImportance importance;