isAvailable property
bool
get
isAvailable
Whether the app is currently running on the Shorebird engine with OTA support.
Implementation
static bool get isAvailable => _updater.isAvailable;
Whether the app is currently running on the Shorebird engine with OTA support.
static bool get isAvailable => _updater.isAvailable;