isStale property
ReadonlySignal<bool>
get
isStale
Reactive signal indicating whether the current data is considered stale.
Implementation
ReadonlySignal<bool> get isStale => _isStale.readonly();
Reactive signal indicating whether the current data is considered stale.
ReadonlySignal<bool> get isStale => _isStale.readonly();