healthyThresholdDuration property
Duration after launch after which startup is considered healthy.
Implementation
final Duration healthyThresholdDuration;
Duration after launch after which startup is considered healthy.
final Duration healthyThresholdDuration;