A class
<a> — anchor / hyperlink element.
Provides convenient shorthands for href, target, and rel.
A(
href: 'https://bloom.dev',
target: '_blank',
rel: 'noopener noreferrer',
text: 'Visit Bloom',
)
Constructors
-
A({String? text, String? className, String? style, Map<
String, String> ? attrs, String? href, String? target, String? rel, List<BloomNode> children = const [], Map<String, BloomEventHandler> ? on, BloomEventHandler? onClick, BloomEventHandler? onMouseEnter, BloomEventHandler? onMouseLeave, BloomEventHandler? onFocus, BloomEventHandler? onBlur}) -
Creates an
<a>anchor element descriptor with hyperlink shorthands. -
A.raw({String? text, String? className, String? style, Map<
String, String> ? attrs, Map<String, BloomEventHandler> ? on, List<BloomNode> children = const []}) -
Const constructor for
<a>without hyperlink shorthands.const
Properties
-
attrs
→ Map<
String, String> ? -
Arbitrary HTML attributes (id, href, placeholder, etc.).
finalinherited
-
children
→ List<
BloomNode> -
Child descriptors nested within this element.
finalinherited
- className → String?
-
CSS class attribute applied to the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
on
→ Map<
String, BloomEventHandler> ? -
Event handlers keyed by DOM event name (click, input, change...).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → String?
-
Inline style — raw CSS string (e.g. "color: red; display: flex;").
finalinherited
- tag → String
-
Lowercase tag name, e.g. "div", "button", "custom-tag".
finalinherited
- text → String?
-
Optional single text child sugar — equivalent to
children: [Text(text)]when no explicit children are given.finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited