animation property
The animation configuration describing keyframes, duration, timing, and fill mode.
Implementation
final BloomAnimation animation;
The animation configuration describing keyframes, duration, timing, and fill mode.
final BloomAnimation animation;