AriaAutocomplete enum

Allowed values for aria-autocomplete.

Indicates whether inputting text could trigger display of predictions.

Input(
  attrs: aria(autocomplete: AriaAutocomplete.list),
)
Inheritance
Available extensions

Values

inline → const AriaAutocomplete
const AriaAutocomplete('inline')
list → const AriaAutocomplete
const AriaAutocomplete('list')
both → const AriaAutocomplete
const AriaAutocomplete('both')
none → const AriaAutocomplete
const AriaAutocomplete('none')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaAutocomplete>
A constant List of the values in this enum, in order of their declaration.