AriaCurrent enum
Allowed values for aria-current.
Indicates the element that represents the current item within a container or set.
Nav(
children: [
A(href: '/home', attrs: aria(current: AriaCurrent.page), text: 'Home'),
],
)
Values
- page → const AriaCurrent
-
const AriaCurrent('page') - step → const AriaCurrent
-
const AriaCurrent('step') - location → const AriaCurrent
-
const AriaCurrent('location') - date → const AriaCurrent
-
const AriaCurrent('date') - time → const AriaCurrent
-
const AriaCurrent('time') - trueValue → const AriaCurrent
-
const AriaCurrent('true') - falseValue → const AriaCurrent
-
const AriaCurrent('false')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The raw WAI-ARIA attribute string value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AriaCurrent> - A constant List of the values in this enum, in order of their declaration.