AriaHasPopup enum

Allowed values for aria-haspopup.

Indicates the availability and type of interactive popup element.

Button(
  attrs: aria(hasPopup: AriaHasPopup.menu, expanded: false),
  text: 'Options',
)
Inheritance
Available extensions

Values

falseValue → const AriaHasPopup
const AriaHasPopup('false')
trueValue → const AriaHasPopup
const AriaHasPopup('true')
const AriaHasPopup('menu')
listbox → const AriaHasPopup
const AriaHasPopup('listbox')
tree → const AriaHasPopup
const AriaHasPopup('tree')
grid → const AriaHasPopup
const AriaHasPopup('grid')
dialog → const AriaHasPopup
const AriaHasPopup('dialog')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaHasPopup>
A constant List of the values in this enum, in order of their declaration.