AriaInvalid enum

Allowed values for aria-invalid.

Indicates that the entered value does not conform to the expected format.

Input(
  attrs: aria(invalidState: AriaInvalid.spelling),
)
Inheritance
Available extensions

Values

trueValue → const AriaInvalid
const AriaInvalid('true')
falseValue → const AriaInvalid
const AriaInvalid('false')
grammar → const AriaInvalid
const AriaInvalid('grammar')
spelling → const AriaInvalid
const AriaInvalid('spelling')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaInvalid>
A constant List of the values in this enum, in order of their declaration.