AriaOrientation enum

Allowed values for aria-orientation.

Defines whether an element's orientation is horizontal, vertical, or unknown/ambiguous.

Div(
  attrs: aria(role: AriaRole.scrollbar, orientation: AriaOrientation.vertical),
)
Inheritance
Available extensions

Values

horizontal → const AriaOrientation
const AriaOrientation('horizontal')
vertical → const AriaOrientation
const AriaOrientation('vertical')
undefined → const AriaOrientation
const AriaOrientation('undefined')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaOrientation>
A constant List of the values in this enum, in order of their declaration.