AriaRelevant enum

Allowed values for aria-relevant.

Indicates what notifications the user agent will trigger when the accessibility tree within a live region is modified.

Div(
  attrs: aria(live: AriaLive.polite, relevant: AriaRelevant.additionsText),
)
Inheritance
Available extensions

Values

additions → const AriaRelevant
const AriaRelevant('additions')
removals → const AriaRelevant
const AriaRelevant('removals')
text → const AriaRelevant
const AriaRelevant('text')
all → const AriaRelevant
const AriaRelevant('all')
additionsText → const AriaRelevant
const AriaRelevant('additions text')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaRelevant>
A constant List of the values in this enum, in order of their declaration.