AriaSort enum

Allowed values for aria-sort.

Indicates if items in a table or grid are sorted in ascending or descending order.

Th(
  attrs: aria(sort: AriaSort.ascending),
  text: 'Name',
)
Inheritance
Available extensions

Values

ascending → const AriaSort
const AriaSort('ascending')
descending → const AriaSort
const AriaSort('descending')
none → const AriaSort
const AriaSort('none')
other → const AriaSort
const AriaSort('other')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaSort>
A constant List of the values in this enum, in order of their declaration.