locale property
The BCP-47 language tag identifying the locale of this catalog (e.g. 'en-US', 'fr-FR', 'de').
Implementation
final String locale;
The BCP-47 language tag identifying the locale of this catalog (e.g. 'en-US', 'fr-FR', 'de').
final String locale;