removeOverride<T> method

void removeOverride<T>([
  1. Type? type
])

Removes a test override registered for generic type T or explicit type.

Restores normal resolution behavior from underlying bindings or parent containers.

container.removeOverride<AuthService>();

Implementation

void removeOverride<T>([Type? type]) {
  _overrides.remove(type ?? T);
}