defaultValue property
T
defaultValue
final
The fallback value returned by useContext when no matching provider exists in the ancestor hierarchy.
Implementation
final T defaultValue;
The fallback value returned by useContext when no matching provider exists in the ancestor hierarchy.
final T defaultValue;