BloomDevToolsEvent class
A recorded diagnostic event emitted by BloomJsDevTools.notify.
Constructors
-
BloomDevToolsEvent({required String type, required Map<
String, dynamic> data, required DateTime timestamp}) -
Creates a diagnostic event record.
const
Properties
-
data
→ Map<
String, dynamic> -
Structured event payload metadata.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp when the diagnostic event occurred.
final
- type → String
-
The diagnostic event identifier string (e.g.
'mount-error','region-created').final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited