code property
The physical key code identifier on the keyboard (e.g. 'KeyA', 'Enter', 'Space').
Populated for keyboard events. Remains null for non-keyboard events.
Implementation
final String? code;
The physical key code identifier on the keyboard (e.g. 'KeyA', 'Enter', 'Space').
Populated for keyboard events. Remains null for non-keyboard events.
final String? code;