key property
The printable key value of the pressed key (e.g. 'Enter', 'Escape', 'a', 'ArrowDown').
Populated for keyboard events (keydown, keyup, keypress). Remains null for non-keyboard events.
Implementation
final String? key;
The printable key value of the pressed key (e.g. 'Enter', 'Escape', 'a', 'ArrowDown').
Populated for keyboard events (keydown, keyup, keypress). Remains null for non-keyboard events.
final String? key;