isDirty property
Computed signal indicating whether any child is dirty or the array membership has changed.
Implementation
@override
late final ReadonlySignal<bool> isDirty;
Computed signal indicating whether any child is dirty or the array membership has changed.
@override
late final ReadonlySignal<bool> isDirty;