length property
int
get
length
Returns the current number of child controls in the array.
Implementation
int get length => fields.value.length;
Returns the current number of child controls in the array.
int get length => fields.value.length;