touch method
Marks this array and all its child controls as touched.
Implementation
@override
void touch() {
isTouched.value = true;
for (final child in fields.value) {
child.touch();
}
}
Marks this array and all its child controls as touched.
@override
void touch() {
isTouched.value = true;
for (final child in fields.value) {
child.touch();
}
}