BloomFireEvent class

Synthetic event dispatcher for simulating DOM events in headless VM unit tests.

Invokes the corresponding BloomEventHandler registered in ElNode.on directly with a synthetic BloomEvent instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

change(ElNode element, {String? value, bool? checked}) → void
Fires a synthetic change event on element with value or checked state.
click(ElNode element) → void
Fires a synthetic click event on element.
custom(ElNode element, String type, {BloomEvent? event}) → void
Fires a synthetic event of arbitrary type on element with an optional custom event payload.
input(ElNode element, {String? value}) → void
Fires a synthetic input event on element with the specified text value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
submit(ElNode element) → void
Fires a synthetic submit event on element.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited