BloomFlexParentData class

Parent data used by RenderBloomFlex to store flex layout properties per child.

Inheritance

Constructors

BloomFlexParentData()

Properties

flexGrow int
Flex grow factor for this child (defaults to 0).
getter/setter pair
flexShrink int
Flex shrink factor for this child (defaults to 1).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextSibling RenderBox?
The next sibling in the parent's child list.
getter/setter pairinherited
offset Offset
The offset at which to paint the child in the parent's coordinate system.
getter/setter pairinherited
previousSibling RenderBox?
The previous sibling in the parent's child list.
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detach() → void
Clear the sibling pointers.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited