rawValue property
dynamic
get
rawValue
Raw untyped value of the control used during form serialization and aggregation.
Implementation
dynamic get rawValue;
Raw untyped value of the control used during form serialization and aggregation.
dynamic get rawValue;