getField method
Returns the BloomFormField registered under name.
Throws StateError if no field with name exists or if it is not a BloomFormField.
Implementation
BloomFormField getField(String name) => getControl<BloomFormField>(name);
Returns the BloomFormField registered under name.
Throws StateError if no field with name exists or if it is not a BloomFormField.
BloomFormField getField(String name) => getControl<BloomFormField>(name);