touch method
Marks this group and all its child controls as touched.
Implementation
@override
void touch() {
isTouched.value = true;
for (final field in _fields.values) {
field.touch();
}
}
Marks this group and all its child controls as touched.
@override
void touch() {
isTouched.value = true;
for (final field in _fields.values) {
field.touch();
}
}