fetch property
The asynchronous fetch function executed to retrieve a single page.
Implementation
final InfiniteQueryFn<TPage, TParam> fetch;
The asynchronous fetch function executed to retrieve a single page.
final InfiniteQueryFn<TPage, TParam> fetch;