getNextPageParam property

GetNextPageParamFn<TPage, TParam> getNextPageParam
final

Function deriving the parameter for the next page from the most recent page and all loaded pages.

Implementation

final GetNextPageParamFn<TPage, TParam> getNextPageParam;