isLoading property
bool
get
isLoading
Whether the query is performing its initial fetch with no pages loaded.
Implementation
bool get isLoading => _status.value == QueryStatus.loading;
Whether the query is performing its initial fetch with no pages loaded.
bool get isLoading => _status.value == QueryStatus.loading;