isStale property
ReadonlySignal<bool>
get
isStale
Reactive signal indicating whether the current cached page data is stale.
Implementation
ReadonlySignal<bool> get isStale => _isStale.readonly();
Reactive signal indicating whether the current cached page data is stale.
ReadonlySignal<bool> get isStale => _isStale.readonly();