activeRegionCount property
Current number of actively mounted reactive region scopes in the browser DOM.
Implementation
static int activeRegionCount = 0;
Current number of actively mounted reactive region scopes in the browser DOM.
static int activeRegionCount = 0;