activeSentinelCount property
Current number of active sentinel comment boundary markers in the browser DOM.
Implementation
static int activeSentinelCount = 0;
Current number of active sentinel comment boundary markers in the browser DOM.
static int activeSentinelCount = 0;