clearEventLog static method
void
clearEventLog()
Clears the in-memory diagnostic event log without modifying listeners or active counters.
Implementation
static void clearEventLog() => _eventLog.clear();
Clears the in-memory diagnostic event log without modifying listeners or active counters.
static void clearEventLog() => _eventLog.clear();