isLoading property
bool
get
isLoading
Whether the query is currently performing its initial fetch with no data available.
Implementation
bool get isLoading => _status.value == QueryStatus.loading;
Whether the query is currently performing its initial fetch with no data available.
bool get isLoading => _status.value == QueryStatus.loading;