history property

List<A> get history

An unmodifiable, chronological history of all actions dispatched to this reducer.

The first element is the oldest dispatched action, and the last element is the most recent. Intended for diagnostic logging, testing, and devtools integration.

Implementation

List<A> get history => List.unmodifiable(_history);