reducerFn property
The pure state-transition function that derives the next state on each dispatch.
Implementation
final BloomReducerFn<S, A> reducerFn;
The pure state-transition function that derives the next state on each dispatch.
final BloomReducerFn<S, A> reducerFn;