loader property

Future Function(Map<String, String> params)? loader
final

Async data loader executed upon navigation before this route renders.

When defined, this route's view is automatically wrapped in a Suspense boundary. The returned future resolves before dataBuilder (or builder) is displayed.

Implementation

final Future<dynamic> Function(Map<String, String> params)? loader;