canActivate abstract method

FutureOr<GuardResult> canActivate(
  1. String location,
  2. Map<String, String> params
)

Evaluates whether navigation to location with extracted route params is allowed.

location contains the full target URL string including any query parameters and hash fragments (e.g. '/search?q=shoes&page=2#top').

Implementation

FutureOr<GuardResult> canActivate(String location, Map<String, String> params);