rawData property
dynamic
rawData
final
The raw decoded JSON object or string that failed to match the contract.
Implementation
final dynamic rawData;
The raw decoded JSON object or string that failed to match the contract.
final dynamic rawData;