contract property
BloomRpcContract?
get
contract
The RPC contract that was executing when the error occurred, or null.
Implementation
BloomRpcContract<dynamic, dynamic>? get contract;
The RPC contract that was executing when the error occurred, or null.
BloomRpcContract<dynamic, dynamic>? get contract;