contract property
The RPC contract that was executing when the error occurred, or null.
Implementation
@override
final BloomRpcContract<dynamic, dynamic>? contract;
The RPC contract that was executing when the error occurred, or null.
@override
final BloomRpcContract<dynamic, dynamic>? contract;