isClientError property
bool
get
isClientError
Whether the status code is a client error in the 4xx range.
Implementation
bool get isClientError => statusCode >= 400 && statusCode < 500;
Whether the status code is a client error in the 4xx range.
bool get isClientError => statusCode >= 400 && statusCode < 500;