isServerError property
bool
get
isServerError
Whether the status code is a server error in the 5xx range.
Implementation
bool get isServerError => statusCode >= 500 && statusCode < 600;
Whether the status code is a server error in the 5xx range.
bool get isServerError => statusCode >= 500 && statusCode < 600;