BloomRpcTimeoutException class

Exception thrown when an RPC request exceeds the configured network timeout duration.

Implemented types

Constructors

BloomRpcTimeoutException({required Duration timeout, BloomRpcContract? contract, Uri? uri, String? message})
Creates a BloomRpcTimeoutException for timeout.

Properties

contract BloomRpcContract?
The RPC contract that was executing when the error occurred, or null.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Error summary message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
The duration limit that was exceeded.
final
uri Uri?
The target URI of the failed request, or null.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited