CommandItemConfig class

Descriptor for a single command item in the command palette.

Constructors

CommandItemConfig({required String label, String? group, String? shortcut, String? icon, required VoidCallback onSelect, bool disabled = false})
const

Properties

disabled bool
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
label String
final
onSelect VoidCallback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited