CommandPaletteConfig class

Configuration descriptor for an active command palette overlay.

Constructors

CommandPaletteConfig({required List<CommandItemConfig> items, String placeholder = 'Type a command or search...', VoidCallback? onClose})

Properties

hashCode int
The hash code for this object.
no setterinherited
items List<CommandItemConfig>
final
onClose VoidCallback?
final
placeholder String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited