value property
T
value
final
The value injected into the ambient zone for child and its descendants.
Implementation
final T value;
The value injected into the ambient zone for child and its descendants.
final T value;