DialogConfig class

Configuration descriptor for a global dialog overlay.

Constructors

DialogConfig({required String title, String? description, BloomNode? body, String? confirmLabel, String? cancelLabel, bool destructive = false, VoidCallback? onConfirm, VoidCallback? onCancel})

Properties

body BloomNode?
final
cancelLabel String?
final
confirmLabel String?
final
description String?
final
destructive bool
final
hashCode int
The hash code for this object.
no setterinherited
onCancel VoidCallback?
final
onConfirm VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited