fallback property
Fallback builder invoked with the caught Object error and StackTrace when builder fails.
Implementation
final BloomNode Function(Object error, StackTrace stackTrace) fallback;
Fallback builder invoked with the caught Object error and StackTrace when builder fails.
final BloomNode Function(Object error, StackTrace stackTrace) fallback;