Fragment class

Fragment grouping sugar.

Groups multiple sibling nodes without introducing an additional wrapper DOM element.

Fragment(
  children: [
    H1(text: 'Title'),
    P(text: 'First paragraph'),
    P(text: 'Second paragraph'),
  ],
)
Inheritance

Constructors

Fragment({required List<BloomNode> children})
Creates a fragment from a named list of children.
const
Fragment.fromList(List<BloomNode> children)
Creates a fragment from a positional list of children.
const

Properties

children List<BloomNode>
The list of child descriptors grouped by this fragment.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited