FragmentNode class

Fragment — groups multiple child nodes without introducing a wrapper DOM element.

DOM Mounting and SSR

  • Browser (mount): Appends each child in children sequentially into the parent DOM container without creating an intermediate container node.
  • SSR (renderToHtml): Renders each child in children sequentially into the output stream with no wrapper tags.

Usually created using the DSL sugar Fragment.

Inheritance

Constructors

FragmentNode([List<BloomNode> children = const []])
Creates a fragment descriptor containing children.
const

Properties

children List<BloomNode>
The list of child descriptors grouped by this fragment.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited