dependency property
T Function()
dependency
final
Reactive computation returning the dependency value of type T.
Implementation
final T Function() dependency;
Reactive computation returning the dependency value of type T.
final T Function() dependency;