MenuItemConfig class

Configuration for a dropdown menu item.

Constructors

const

Properties

destructive bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
icon String?
final
label String
final
onClick → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited