onUnmount property
void Function()?
onUnmount
final
Callback executed synchronously when child is removed from the DOM.
Implementation
final void Function()? onUnmount;
Callback executed synchronously when child is removed from the DOM.
final void Function()? onUnmount;