MutationStatus enum

Lifecycle execution status of a BloomMutation.

Inheritance
Available extensions

Values

idle → const MutationStatus

Mutation has not been executed yet or was reset via BloomMutation.reset.

pending → const MutationStatus

Mutation execution is actively in-flight.

success → const MutationStatus

Mutation completed successfully and result data is accessible in BloomMutation.data.

error → const MutationStatus

Mutation execution failed with an exception, accessible in BloomMutation.error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MutationStatus>
A constant List of the values in this enum, in order of their declaration.