NavMenuItem class

Configuration descriptor for a navigation menu item.

Constructors

const

Properties

active bool
final
content BloomNode?
final
hashCode int
The hash code for this object.
no setterinherited
href String?
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited