QueryStatus enum

Execution status lifecycle of a BloomQuery.

Inheritance
Available extensions

Values

idle → const QueryStatus

Query is initialized but has not commenced fetching (or BloomQuery.enabled is false).

loading → const QueryStatus

Initial network fetch is in progress with no cached data available.

success → const QueryStatus

Query resolved successfully and valid data is accessible in BloomQuery.data.

error → const QueryStatus

Query execution encountered an unhandled exception, accessible in BloomQuery.error.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<QueryStatus>
A constant List of the values in this enum, in order of their declaration.