channel property
Channel identifier associated with this message, or null for system-level messages like ping/pong.
Implementation
final String? channel;
Channel identifier associated with this message, or null for system-level messages like ping/pong.
final String? channel;