isSynchronous property
bool
get
isSynchronous
Whether this host executes synchronously without deferral or time-slicing (e.g. in fast SSR).
Implementation
bool get isSynchronous;
Whether this host executes synchronously without deferral or time-slicing (e.g. in fast SSR).
bool get isSynchronous;