yieldToHost abstract method
Yields execution to the host event loop, completing when the platform is ready to resume.
Implementation
Future<void> yieldToHost();
Yields execution to the host event loop, completing when the platform is ready to resume.
Future<void> yieldToHost();