cancel abstract method
void
cancel()
Cancels this task if it has not yet started or completed.
If the task is already executing or completed, this is a no-op.
Implementation
void cancel();
Cancels this task if it has not yet started or completed.
If the task is already executing or completed, this is a no-op.
void cancel();