future property
Future<T>
get
future
A future resolving when the task execution completes, or completing with an error.
Implementation
Future<T> get future;
A future resolving when the task execution completes, or completing with an error.
Future<T> get future;