css property

String css
final

The transformed CSS stylesheet with all local class selectors scoped.

Contains the rewritten CSS rules where every local class selector has been suffixed with the deterministic 7-character hash. This is the exact CSS string embedded into node and injected into <style> elements.

final styles = scopedCss('.btn { color: white; }', name: 'btn');
print(styles.css); // '.btn_btn__a1b2c3d { color: white; }'

Implementation

final String css;