get method

String get(
  1. String className
)

Looks up the generated scoped class name for author className.

Named method equivalent to operator [] and call. Returns the scoped class name if defined in the stylesheet, or className unchanged if not found.

final cls = styles.get('card');

Implementation

String get(String className) => classes[className] ?? className;