SheetConfig class

Configuration descriptor for slide-over side panels and drawers.

Constructors

SheetConfig({required String title, String? description, BloomNode? body, String side = 'right', bool showCloseButton = true, VoidCallback? onClose})

Properties

body BloomNode?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
onClose VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
final
side String
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited