Style class

Inline stylesheet sugar.

Emits a <style> block containing css.

const customStyles = Style('''
  .custom-card {
    padding: 16px;
    border-radius: 8px;
    background: #14141a;
  }
''');
Inheritance

Constructors

Style(String css)
Creates an inline <style> element descriptor with css.
const

Properties

css String
The raw CSS stylesheet content.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited