errorBuilder property
Optional error builder invoked if resource rejects with an exception.
Implementation
final BloomNode Function(Object error, StackTrace stackTrace)? errorBuilder;
Optional error builder invoked if resource rejects with an exception.
final BloomNode Function(Object error, StackTrace stackTrace)? errorBuilder;