Text class

Plain text node sugar.

Mounts to a web.Text node in the browser and escapes text in SSR.

P(
  children: [
    const Text('Hello, '),
    Span(className: 'font-bold', text: 'World!'),
  ],
)
Inheritance

Constructors

Text(String text)
Creates a plain text node with text.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The raw text content of this node.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited