TextNode class

Plain text leaf descriptor.

Mounts to a single web.Text DOM node via web.document.createTextNode(text) in the browser. During server-side rendering (renderToHtml), the text is sanitized via escapeHtml to prevent cross-site scripting (XSS).

Usually created using the DSL sugar Text.

Inheritance

Constructors

TextNode(String text)
Creates a text leaf descriptor with text.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The raw text content of this node.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited