ToastItem class

Descriptor representing an active toast notification item.

Constructors

ToastItem({required String id, required String message, required ToastVariant variant, required DateTime createdAt, String? actionLabel, void onAction()?})

Properties

actionLabel String?
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
message String
final
onAction → void Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variant ToastVariant
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited