VisuallyHiddenStyle class

Style descriptor for embedding screen-reader utility CSS rules.

Div(
  children: [
    const VisuallyHiddenStyle(),
    // ...
  ],
)
Inheritance

Constructors

VisuallyHiddenStyle()
const

Properties

css String
The raw CSS stylesheet content.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited