createContext<T> function
Creates a typed ambient BloomContext with defaultValue.
Returns a context token that can be passed to BloomContext.provide to inject a value into a subtree, and to useContext to read the nearest provided value within that subtree.
final authContext = createContext<User?>(null);
Implementation
BloomContext<T> createContext<T>(T defaultValue) => BloomContext<T>(defaultValue);