removeOverride<T> method
Removes an active test override for type T (or explicitly specified type).
Implementation
void removeOverride<T>([Type? type]) {
_overrides.remove(type ?? T);
}
Removes an active test override for type T (or explicitly specified type).
void removeOverride<T>([Type? type]) {
_overrides.remove(type ?? T);
}