clear static method
void
clear()
Clears all loaded environment variables from the internal in-memory store.
Implementation
static void clear() => _env.clear();
Clears all loaded environment variables from the internal in-memory store.
static void clear() => _env.clear();