isSecure property
Whether the request was received over a secure HTTPS connection or behind an SSL proxy.
Implementation
final bool isSecure;
Whether the request was received over a secure HTTPS connection or behind an SSL proxy.
final bool isSecure;