isStreaming property
bool
get
isStreaming
Whether this request's body is delivered via an unbuffered stream rather than pre-buffered bytes.
Implementation
bool get isStreaming => _streamBody != null;
Whether this request's body is delivered via an unbuffered stream rather than pre-buffered bytes.
bool get isStreaming => _streamBody != null;