text method
Decodes and returns the raw request body as a UTF-8 string.
Returns an empty string if rawBody is empty. Throws StateError if this request is a streaming request.
Implementation
String text() => utf8.decode(rawBody);
Decodes and returns the raw request body as a UTF-8 string.
Returns an empty string if rawBody is empty. Throws StateError if this request is a streaming request.
String text() => utf8.decode(rawBody);