isStreaming property
bool
get
isStreaming
Whether this response delivers its payload incrementally via a byte stream.
Implementation
bool get isStreaming => _bodyStream != null;
Whether this response delivers its payload incrementally via a byte stream.
bool get isStreaming => _bodyStream != null;