inject<T> method
T
inject<T>()
Resolves dependency of type T within this test scope.
Throws StateError if T cannot be resolved from this scope or its parent.
Implementation
T inject<T>() => container.inject<T>();