injectOrNull<T> method
T?
injectOrNull<T>()
Resolves optional dependency of type T within this test scope, or returns null.
Implementation
T? injectOrNull<T>() => container.injectOrNull<T>();
Resolves optional dependency of type T within this test scope, or returns null.
T? injectOrNull<T>() => container.injectOrNull<T>();