injectOrNull<T> function

T? injectOrNull<T>()

Resolves an optional dependency of type T from the global active Bloom container, or returns null if not registered.

Example

final metrics = injectOrNull<MetricsCollector>();

Implementation

T? injectOrNull<T>() => globalContainer.injectOrNull<T>();