isReady property
ReadonlySignal<bool>
get
isReady
Reactive signal indicating whether the patch is downloaded and ready to apply.
Implementation
static ReadonlySignal<bool> get isReady => _isReady;
Reactive signal indicating whether the patch is downloaded and ready to apply.
static ReadonlySignal<bool> get isReady => _isReady;