BloomPermission enum

Native hardware and system permission types supported by Bloom applications.

Example:

final status = await BloomPermissions.check(BloomPermission.camera);
Inheritance
Available extensions

Values

camera → const BloomPermission

Camera hardware capture permission.

notifications → const BloomPermission

Push and local notifications alert permission.

storage → const BloomPermission

Device filesystem and photo gallery storage permission.

microphone → const BloomPermission

Audio microphone recording permission.

location → const BloomPermission

Device GPS and fine/coarse location access permission.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BloomPermission>
A constant List of the values in this enum, in order of their declaration.