openAppSettings static method
Opens the device application settings screen so the user can manually enable permissions.
Returns true if the settings screen could be opened.
Example:
await BloomPermissions.openAppSettings();
Implementation
static Future<bool> openAppSettings() async {
return ph.openAppSettings();
}