ConflictPolicy enum
Conflict resolution strategy when replaying offline mutations against the server.
Example:
await queue.enqueue(
mutationType: 'update_profile',
payload: {'name': 'New Name'},
conflictPolicy: ConflictPolicy.clientWins,
);
Values
- clientWins → const ConflictPolicy
-
Keep the client mutation and override conflicting server state.
- serverWins → const ConflictPolicy
-
Discard the client mutation and keep existing server state.
- custom → const ConflictPolicy
-
Invoke a custom CustomConflictResolver to merge or handle conflicts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ConflictPolicy> - A constant List of the values in this enum, in order of their declaration.