AriaChecked enum
Allowed values for aria-checked.
Indicates the current "checked" state of checkboxes, radio buttons, and other widgets.
Div(
attrs: aria(role: AriaRole.checkbox, checkedState: AriaChecked.mixed),
text: 'Select All',
)
Values
- trueValue → const AriaChecked
-
const AriaChecked('true') - falseValue → const AriaChecked
-
const AriaChecked('false') - mixed → const AriaChecked
-
const AriaChecked('mixed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The raw WAI-ARIA attribute string value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AriaChecked> - A constant List of the values in this enum, in order of their declaration.