AriaLive enum

Allowed values for aria-live.

Controls how screen readers announce dynamic updates to a live region.

Div(
  attrs: aria(live: AriaLive.polite, atomic: true),
  text: 'Status updated',
)
Inheritance
Available extensions

Values

off → const AriaLive

Updates are not announced automatically.

const AriaLive('off')
polite → const AriaLive

Updates are announced at the next graceful opportunity (user is idle).

const AriaLive('polite')
assertive → const AriaLive

Updates interrupt the user immediately.

const AriaLive('assertive')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The raw WAI-ARIA attribute string value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AriaLive>
A constant List of the values in this enum, in order of their declaration.