AriaPressed enum
Allowed values for aria-pressed.
Indicates the current "pressed" state of a toggle button.
Button(
attrs: aria(pressedState: AriaPressed.mixed),
text: 'Mute All',
)
Values
- trueValue → const AriaPressed
-
const AriaPressed('true') - falseValue → const AriaPressed
-
const AriaPressed('false') - mixed → const AriaPressed
-
const AriaPressed('mixed')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The raw WAI-ARIA attribute string value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AriaPressed> - A constant List of the values in this enum, in order of their declaration.