BloomAnimationPresets class
Ready-to-use BloomAnimation presets for common UI transitions.
Access preset instances via BloomAnimationPresets.fadeIn, BloomAnimationPresets.scaleIn, etc.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- fadeIn → const BloomAnimation
-
Fades element opacity from
0to1over 300 milliseconds. - fadeOut → const BloomAnimation
-
Fades element opacity from
1to0over 300 milliseconds. - pulse → const BloomAnimation
-
Continuously pulses element scale between
1.0and1.05in an infinite loop. - scaleIn → const BloomAnimation
-
Scales element from
0.8to1.0with a concurrent fade in. - slideInLeft → const BloomAnimation
-
Translates element horizontally from
-100%to0with a concurrent fade in. - slideInRight → const BloomAnimation
-
Translates element horizontally from
100%to0with a concurrent fade in.