BloomArrayAsyncValidator<T extends BloomFormControl> typedef
BloomArrayAsyncValidator<T extends BloomFormControl> =
Future<String?> Function(List<T> controls)
Signature for an asynchronous validator callback on a BloomFieldArray.
Evaluates the list of child BloomFormControl items in the array.
Returns a Future completing with an error string on failure or null when valid.
Future<String?> checkUniqueNames(List<BloomFormField> fields) async {
final names = fields.map((f) => f.value.value).toSet();
return names.length == fields.length ? null : 'All names must be unique.';
}
Implementation
typedef BloomArrayAsyncValidator<T extends BloomFormControl> = Future<String?>
Function(List<T> controls);