BloomDateTimeClientI18n extension
Convenience internationalization extension on DateTime for localized formatting.
- on
Methods
-
toLocalizedDate(
{String? locale, String? pattern, DateFormatStyle? style}) → String -
Available on DateTime, provided by the BloomDateTimeClientI18n extension
Formats this date as a localized date string. -
toLocalizedDateTime(
{String? locale, String? pattern, DateFormatStyle? style}) → String -
Available on DateTime, provided by the BloomDateTimeClientI18n extension
Formats this date as a localized date and time string. -
toLocalizedRelativeTime(
{DateTime? relativeTo, String? locale}) → String -
Available on DateTime, provided by the BloomDateTimeClientI18n extension
Formats this date as a relative time string (e.g. "5 minutes ago").