BloomFireEvent class
Synthetic event dispatcher for simulating DOM events in headless VM unit tests.
Invokes the corresponding BloomEventHandler registered in ElNode.on directly with a synthetic BloomEvent instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
change(
ElNode element, {String? value, bool? checked}) → void -
Fires a synthetic
changeevent onelementwithvalueorcheckedstate. -
click(
ElNode element) → void -
Fires a synthetic
clickevent onelement. -
custom(
ElNode element, String type, {BloomEvent? event}) → void -
Fires a synthetic event of arbitrary
typeonelementwith an optional customeventpayload. -
input(
ElNode element, {String? value}) → void -
Fires a synthetic
inputevent onelementwith the specified textvalue. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submit(
ElNode element) → void -
Fires a synthetic
submitevent onelement. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited