custom method
Fires a synthetic event of arbitrary type on element with an optional custom event payload.
Throws StateError if element has no handler registered for type.
Implementation
void custom(ElNode element, String type, {BloomEvent? event}) =>
_dispatch(element, type, override: event);