validate abstract method
Validates this control and any child controls synchronously, updating errors.
Cancels any pending debounced async validation and resets isValidating to false.
Returns true if valid and errors is empty; false otherwise.
Implementation
bool validate();