getNextPageParam property
Function deriving the parameter for the next page from the most recent page and all loaded pages.
Implementation
final GetNextPageParamFn<TPage, TParam> getNextPageParam;
Function deriving the parameter for the next page from the most recent page and all loaded pages.
final GetNextPageParamFn<TPage, TParam> getNextPageParam;