BloomRpcCancelledException class
Exception thrown when an in-flight RPC request is aborted via BloomRpcCancelToken.
- Implemented types
Constructors
- BloomRpcCancelledException({String reason = 'Request was cancelled', BloomRpcContract? contract, Uri? uri})
-
Creates a BloomRpcCancelledException with cancellation
reason.
Properties
- contract → BloomRpcContract?
-
The RPC contract that was executing when the error occurred, or
null.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error summary message.
final
- reason → String
-
Optional cancellation reason.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri?
-
The target URI of the failed request, or
null.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited