BloomRpcEncodeException class
Exception thrown when serializing input data into a request payload fails before transmission.
- Implemented types
Constructors
- BloomRpcEncodeException({required Object cause, BloomRpcContract? contract, Uri? uri, StackTrace? stackTrace, String? message})
-
Creates a BloomRpcEncodeException with encoding
cause.
Properties
- cause → Object
-
The underlying encoding error.
final
- contract → BloomRpcContract?
-
The RPC contract that was executing when the error occurred, or
null.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error summary message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Stack trace from the encoder failure.
final
- uri → Uri?
-
The target URI of the failed request, or
null.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited