BloomRpcException class abstract

Abstract base exception class for all RPC errors.

Implemented types

Constructors

BloomRpcException()

Properties

contract BloomRpcContract?
The RPC contract that was executing when the error occurred, or null.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
Error summary message.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri?
The target URI of the failed request, or null.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited