BloomRpcPathParameterException class
Exception thrown when a required path parameter in a contract path template is missing.
- Implemented types
Constructors
- BloomRpcPathParameterException({required String paramName, required String pathTemplate, required String method, BloomRpcContract? contract, Uri? uri})
-
Creates a BloomRpcPathParameterException naming the missing
paramName.
Properties
- contract → BloomRpcContract?
-
The RPC contract that was executing when the error occurred, or
null.final - hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Error summary message.
final
- method → String
-
The HTTP method of the endpoint.
final
- paramName → String
-
The name of the missing path parameter.
final
- pathTemplate → String
-
The path template where the parameter was declared.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri → Uri?
-
The target URI of the failed request, or
null.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited