BloomRpcServerRequest class
Pure-Dart abstraction representing an incoming HTTP server request for RPC routing.
Decoupled from specific server runtimes (such as bloom_server or Shelf), allowing
contract bindings to be executed in any server environment or during SSR testing.
Constructors
-
BloomRpcServerRequest({required String method, required String path, Map<
String, String> headers = const {}, Map<String, String> queryParams = const {}, dynamic body, Object? rawRequest, Map<String, Object?> context = const {}}) -
Creates a BloomRpcServerRequest representing an incoming HTTP request.
const
Properties
- body → dynamic
-
Raw request body string or decoded JSON object.
final
-
context
→ Map<
String, Object?> -
Arbitrary request context attributes (e.g. authenticated user, trace IDs).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Request headers map.
final
- method → String
-
HTTP method of the request (e.g.
'GET','POST').final - path → String
-
Target path of the request (e.g.
'/api/v1/tasks/123').final -
queryParams
→ Map<
String, String> -
Parsed query parameters map.
final
- rawRequest → Object?
-
Ambient server request object (e.g.
BloomRequestor context token).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited