BloomTextDirection enum
Text direction representation for bidirectional script layout.
Encapsulates left-to-right (BloomTextDirection.ltr) and right-to-left
(BloomTextDirection.rtl) scripts and their corresponding HTML dir attribute values.
See also:
- isRtl, tests whether a locale uses RTL script.
- getTextDirection, resolves text direction for a locale.
- dirAttribute, helper generating a
{ 'dir': '...' }attribute map.
Values
- ltr → const BloomTextDirection
-
Left-to-right text layout direction (used by Latin, Cyrillic, Greek, Han, etc.).
const BloomTextDirection('ltr') - rtl → const BloomTextDirection
-
Right-to-left text layout direction (used by Arabic, Hebrew, Persian, Urdu, etc.).
const BloomTextDirection('rtl')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The raw HTML
dirattribute string value ("ltr"or"rtl").final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BloomTextDirection> - A constant List of the values in this enum, in order of their declaration.