Fragment class
Fragment grouping sugar.
Groups multiple sibling nodes without introducing an additional wrapper DOM element.
Fragment(
children: [
H1(text: 'Title'),
P(text: 'First paragraph'),
P(text: 'Second paragraph'),
],
)
- Inheritance
-
- Object
- BloomNode
- FragmentNode
- Fragment
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited