detach method

void detach()

Detaches the element and resets this ref to unmounted state.

Called internally by the Bloom mount engine when the enclosing subtree is unmounted.

Implementation

void detach() => _value = null;