value property
T
get
value
The mounted DOM element instance.
Throws StateError if accessed before the element has mounted to the DOM or after it has been unmounted/disposed. Check isMounted before accessing value if mounting timing is uncertain.
Implementation
T get value => _value ?? (throw StateError('Ref<$T> not yet mounted'));