Text class
Plain text node sugar.
Mounts to a web.Text node in the browser and escapes text in SSR.
P(
children: [
const Text('Hello, '),
Span(className: 'font-bold', text: 'World!'),
],
)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited